==> alfred-ui-native-components-0.0.159.tgz: package/ui/widgets/details/tripleDoor/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText,
  DoorClosedIcon,
  DoorOpenIcon,
  LabelMediumText } from '../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../atoms/thumbs';
import { TripleDoorWidgetDetailModel } from '../widgetDetailModels';
import { TripleSlider } from '../../../molecules';
import { styles } from './styles';

const stateTypes = {
  UNLOCK: 'OFF',
  LOCK: 'ON',
  EMPTY: 'EMPTY',
};

const stateToNumber = {
  [stateTypes.LOCK]: 0,
  [stateTypes.UNLOCK]: 2,
  [stateTypes.EMPTY]: 1,
};

export const TripleDoorWidgetDetail: FC<TripleDoorWidgetDetailModel> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  defaultValue = stateTypes.EMPTY,
  id,
  onUpdateData,
  loading = false,
}) => {
  const actionTypes = {
    LOCK: 0,
    UNLOCK: 2,
  };

  const onChange = (value: number) => {
    onUpdateData && value === actionTypes.UNLOCK && onUpdateData({ id, value: stateTypes.UNLOCK });
    onUpdateData && value === actionTypes.LOCK && onUpdateData({ id, value: stateTypes.LOCK });
  };

  return (
    <View>
      <View style={styles().tripleDoorInfoTextBlockDetail}>
        <LabelMediumText>{title}</LabelMediumText>
        {!loading && <Body2RegularText color={styles().tripleDoorInfoTextBlockDetail.color}>{subtitle}</Body2RegularText>}
        {loading &&
          <Body2RegularText
            color={styles().tripleDoorInfoTextBlockDetail.color}
          >
            {loadingInfoTextOptions?.option1}
          </Body2RegularText>}
      </View>
      <TripleSlider
        defaultValue={stateToNumber[defaultValue]}
        ThumbComponent={loading ? SpinnerThumb : DragThumb}
        IconLeft={DoorClosedIcon}
        IconRight={DoorOpenIcon}
        onStateChange={onChange}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/widgets/details/tripleDoor/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText,
  DoorClosedIcon,
  DoorOpenIcon,
  LabelMediumText } from '../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../atoms/thumbs';
import { TripleDoorWidgetDetailModel } from '../widgetDetailModels';
import { TripleSlider } from '../../../molecules';
import { styles } from './styles';

const stateTypes = {
  UNLOCK: 'OFF',
  LOCK: 'ON',
  EMPTY: 'EMPTY',
};

const stateToNumber = {
  [stateTypes.LOCK]: 0,
  [stateTypes.UNLOCK]: 2,
  [stateTypes.EMPTY]: 1,
};

export const TripleDoorWidgetDetail: FC<TripleDoorWidgetDetailModel> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  defaultValue = stateTypes.EMPTY,
  id,
  onUpdateData,
  loading = false,
}) => {
  const actionTypes = {
    LOCK: 0,
    UNLOCK: 2,
  };

  const onChange = (value: number) => {
    onUpdateData && value === actionTypes.UNLOCK && onUpdateData({ id, value: stateTypes.UNLOCK });
    onUpdateData && value === actionTypes.LOCK && onUpdateData({ id, value: stateTypes.LOCK });
  };

  return (
    <View>
      <View style={styles().tripleDoorInfoTextBlockDetail}>
        <LabelMediumText>{title}</LabelMediumText>
        {!loading &&
          <Body2RegularText color={styles().tripleDoorInfoTextBlockDetail.color}>{subtitle}</Body2RegularText>}
        {loading &&
          <Body2RegularText
            color={styles().tripleDoorInfoTextBlockDetail.color}
          >
            {loadingInfoTextOptions?.option1}
          </Body2RegularText>}
      </View>
      <TripleSlider
        defaultValue={stateToNumber[defaultValue]}
        ThumbComponent={loading ? SpinnerThumb : DragThumb}
        IconLeft={DoorClosedIcon}
        IconRight={DoorOpenIcon}
        onStateChange={onChange}
      />
    </View>
  );
};
